@@ -6,7 +6,7 @@
     Allow graphviz-formatted graphs to be included in Sphinx-generated
     documents inline.
 
-    :copyright: Copyright 2007-2017 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2018 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -25,7 +25,7 @@ from docutils.statemachine import ViewList
 
 import sphinx
 from sphinx.errors import SphinxError
-from sphinx.locale import _
+from sphinx.locale import _, __
 from sphinx.util import logging
 from sphinx.util.i18n import search_image_for_language
 from sphinx.util.osutil import ensuredir, ENOENT, EPIPE, EINVAL
@@ -93,8 +93,8 @@ class Graphviz(Directive):
             document = self.state.document
             if self.content:
                 return [document.reporter.warning(
-                    _('Graphviz directive cannot have both content and '
-                      'a filename argument'), line=self.lineno)]
+                    __('Graphviz directive cannot have both content and '
+                       'a filename argument'), line=self.lineno)]
             env = self.state.document.settings.env
             argument = search_image_for_language(self.arguments[0], env)
             rel_filename, filename = env.relfn2path(argument)
@@ -104,13 +104,13 @@ class Graphviz(Directive):
                     dotcode = fp.read()
             except (IOError, OSError):
                 return [document.reporter.warning(
-                    _('External Graphviz file %r not found or reading '
-                      'it failed') % filename, line=self.lineno)]
+                    __('External Graphviz file %r not found or reading '
+                       'it failed') % filename, line=self.lineno)]
         else:
             dotcode = '\n'.join(self.content)
             if not dotcode.strip():
                 return [self.state_machine.reporter.warning(
-                    _('Ignoring "graphviz" directive without content.'),
+                    __('Ignoring "graphviz" directive without content.'),
                     line=self.lineno)]
         node = graphviz()
         node['code'] = dotcode
@@ -201,8 +201,8 @@ def render_dot(self, code, options, format, prefix='graphviz'):
     except OSError as err:
         if err.errno != ENOENT:   # No such file or directory
             raise
-        logger.warning(_('dot command %r cannot be run (needed for graphviz '
-                         'output), check the graphviz_dot setting'), graphviz_dot)
+        logger.warning(__('dot command %r cannot be run (needed for graphviz '
+                          'output), check the graphviz_dot setting'), graphviz_dot)
         if not hasattr(self.builder, '_graphviz_warned_dot'):
             self.builder._graphviz_warned_dot = {}
         self.builder._graphviz_warned_dot[graphviz_dot] = True
@@ -219,11 +219,11 @@ def render_dot(self, code, options, format, prefix='graphviz'):
         stdout, stderr = p.stdout.read(), p.stderr.read()
         p.wait()
     if p.returncode != 0:
-        raise GraphvizError(_('dot exited with error:\n[stderr]\n%s\n'
-                              '[stdout]\n%s') % (stderr, stdout))
+        raise GraphvizError(__('dot exited with error:\n[stderr]\n%s\n'
+                               '[stdout]\n%s') % (stderr, stdout))
     if not path.isfile(outfn):
-        raise GraphvizError(_('dot did not produce an output file:\n[stderr]\n%s\n'
-                              '[stdout]\n%s') % (stderr, stdout))
+        raise GraphvizError(__('dot did not produce an output file:\n[stderr]\n%s\n'
+                               '[stdout]\n%s') % (stderr, stdout))
     return relfn, outfn
 
 
@@ -233,8 +233,8 @@ def render_dot_html(self, node, code, options, prefix='graphviz',
     format = self.builder.config.graphviz_output_format
     try:
         if format not in ('png', 'svg'):
-            raise GraphvizError(_("graphviz_output_format must be one of 'png', "
-                                  "'svg', but is %r") % format)
+            raise GraphvizError(__("graphviz_output_format must be one of 'png', "
+                                   "'svg', but is %r") % format)
         fname, outfn = render_dot(self, code, options, format, prefix)
     except GraphvizError as exc:
         logger.warning('dot code %r: ' % code + str(exc))
@@ -246,14 +246,14 @@ def render_dot_html(self, node, code, options, prefix='graphviz',
         if alt is None:
             alt = node.get('alt', self.encode(code).strip())
         imgcss = imgcls and 'class="%s"' % imgcls or ''
+        if 'align' in node:
+            self.body.append('<div align="%s" class="align-%s">' %
+                             (node['align'], node['align']))
         if format == 'svg':
             svgtag = '''<object data="%s" type="image/svg+xml">
             <p class="warning">%s</p></object>\n''' % (fname, alt)
             self.body.append(svgtag)
         else:
-            if 'align' in node:
-                self.body.append('<div align="%s" class="align-%s">' %
-                                 (node['align'], node['align']))
             with open(outfn + '.map', 'rb') as mapfile:
                 imgmap = mapfile.readlines()
             if len(imgmap) == 2:
@@ -266,8 +266,8 @@ def render_dot_html(self, node, code, options, prefix='graphviz',
                 self.body.append('<img src="%s" alt="%s" usemap="#%s" %s/>\n' %
                                  (fname, alt, mapname, imgcss))
                 self.body.extend([item.decode('utf-8') for item in imgmap])
-            if 'align' in node:
-                self.body.append('</div>\n')
+        if 'align' in node:
+            self.body.append('</div>\n')
 
     raise nodes.SkipNode
 
@@ -286,24 +286,26 @@ def render_dot_latex(self, node, code, options, prefix='graphviz'):
         raise nodes.SkipNode
 
     is_inline = self.is_inline(node)
-    if is_inline:
-        para_separator = ''
-    else:
-        para_separator = '\n'
 
-    if fname is not None:
-        post = None  # type: unicode
-        if not is_inline and 'align' in node:
+    if not is_inline:
+        pre = ''
+        post = ''
+        if 'align' in node:
             if node['align'] == 'left':
-                self.body.append('{')
-                post = '\\hspace*{\\fill}}'
+                pre = '{'
+                post = r'\hspace*{\fill}}'
             elif node['align'] == 'right':
-                self.body.append('{\\hspace*{\\fill}')
+                pre = r'{\hspace*{\fill}'
                 post = '}'
-        self.body.append('%s\\includegraphics{%s}%s' %
-                         (para_separator, fname, para_separator))
-        if post:
-            self.body.append(post)
+            elif node['align'] == 'center':
+                pre = r'{\hfill'
+                post = r'\hspace*{\fill}}'
+        self.body.append('\n%s' % pre)
+
+    self.body.append(r'\includegraphics{%s}' % fname)
+
+    if not is_inline:
+        self.body.append('%s\n' % post)
 
     raise nodes.SkipNode
 
